abacusai.api_class.python_functions — AbacusAI documentation

# abacusai.api_class.python_functions

## Classes

`PythonFunctionArgument` | A config class for python function arguments
`OutputVariableMapping` | A config class for python function arguments

## Module Contents

class abacusai.api_class.python_functions.PythonFunctionArgument

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for python function arguments

  Parameters:

    - variable_type (PythonFunctionArgumentType) – The type of the python function argument

    - name (str) – The name of the python function variable

    - is_required (bool) – Whether the argument is required

    - value (Any) – The value of the argument

    - pipeline_variable (str) – The name of the pipeline variable to use as the value

    - description (str) – The description of the argument

    - item_type (str) – Type of items when variable_type is LIST

  variable_type: abacusai.api_class.enums.PythonFunctionArgumentType = None
  name: str = None
  is_required: bool = True
  value: Any = None
  pipeline_variable: str = None
  description: str = None
  item_type: str = None

class abacusai.api_class.python_functions.OutputVariableMapping

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for python function arguments

  Parameters:

    - variable_type (PythonFunctionOutputArgumentType) – The type of the python function output argument

    - name (str) – The name of the python function variable

  variable_type: abacusai.api_class.enums.PythonFunctionOutputArgumentType = None
  name: str = None